import path from 'path';
import { getAfterReadHook } from '../hooks/afterRead.js';
export const getFields = ({ adapter, collection, disablePayloadAccessControl, generateFileURL, prefix })=>{
    const baseURLField = {
        name: 'url',
        type: 'text',
        admin: {
            hidden: true,
            readOnly: true
        },
        label: 'URL'
    };
    const basePrefixField = {
        name: 'prefix',
        type: 'text',
        admin: {
            hidden: true,
            readOnly: true
        }
    };
    const fields = [
        ...collection.fields,
        ...adapter.fields || []
    ];
    // Inject a hook into all URL fields to generate URLs
    let existingURLFieldIndex = -1;
    const existingURLField = fields.find((existingField, i)=>{
        if ('name' in existingField && existingField.name === 'url') {
            existingURLFieldIndex = i;
            return true;
        }
        return false;
    });
    if (existingURLFieldIndex > -1) {
        fields.splice(existingURLFieldIndex, 1);
    }
    fields.push({
        ...baseURLField,
        ...existingURLField || {},
        hooks: {
            afterRead: [
                getAfterReadHook({
                    adapter,
                    collection,
                    disablePayloadAccessControl,
                    generateFileURL
                }),
                ...existingURLField?.hooks?.afterRead || []
            ]
        }
    });
    if (typeof collection.upload === 'object' && collection.upload.imageSizes) {
        let existingSizesFieldIndex = -1;
        const existingSizesField = fields.find((existingField, i)=>{
            if ('name' in existingField && existingField.name === 'sizes') {
                existingSizesFieldIndex = i;
                return true;
            }
            return false;
        });
        if (existingSizesFieldIndex > -1) {
            fields.splice(existingSizesFieldIndex, 1);
        }
        const sizesField = {
            ...existingSizesField || {},
            name: 'sizes',
            type: 'group',
            admin: {
                hidden: true
            },
            fields: collection.upload.imageSizes.map((size)=>{
                const existingSizeField = existingSizesField?.fields.find((existingField)=>'name' in existingField && existingField.name === size.name);
                const existingSizeURLField = existingSizeField?.fields.find((existingField)=>'name' in existingField && existingField.name === 'url');
                return {
                    ...existingSizeField,
                    name: size.name,
                    type: 'group',
                    fields: [
                        ...adapter.fields || [],
                        {
                            ...existingSizeURLField || {},
                            ...baseURLField,
                            hooks: {
                                afterRead: [
                                    getAfterReadHook({
                                        adapter,
                                        collection,
                                        disablePayloadAccessControl,
                                        generateFileURL,
                                        size
                                    }),
                                    ...existingSizeURLField?.hooks?.afterRead || []
                                ]
                            }
                        }
                    ]
                };
            })
        };
        fields.push(sizesField);
    }
    // If prefix is enabled, save it to db
    if (typeof prefix !== 'undefined') {
        let existingPrefixFieldIndex = -1;
        const existingPrefixField = fields.find((existingField, i)=>{
            if ('name' in existingField && existingField.name === 'prefix') {
                existingPrefixFieldIndex = i;
                return true;
            }
            return false;
        });
        if (existingPrefixFieldIndex > -1) {
            fields.splice(existingPrefixFieldIndex, 1);
        }
        fields.push({
            ...basePrefixField,
            ...existingPrefixField || {},
            defaultValue: path.posix.join(prefix)
        });
    }
    return fields;
};

//# sourceMappingURL=getFields.js.map